pub fn graph_diff(
old: &KnowledgeGraph,
new: &KnowledgeGraph,
) -> HashMap<String, Value>Expand description
Compare two graph snapshots and return a summary of changes.
pub fn graph_diff(
old: &KnowledgeGraph,
new: &KnowledgeGraph,
) -> HashMap<String, Value>Compare two graph snapshots and return a summary of changes.