Module temporal

Module temporal 

Temporal graph analysis via git history integration.

Correlates graph nodes with git commit history to identify high-risk nodes: frequently modified code with high connectivity.

Functions

temporal_analysis
Analyze temporal risk by correlating graph nodes with git history.